@@ -1,14 +1,14 @@
 from interactions.ext import Base, Version
 from .extension import Persistence
 
-version = Version(version="0.1.0")
+version = Version(version="1.0.0-beta.1")
 
 base = Base(
     name="Persistence",
     version=version,
     link=f"https://github.com/dworv/interactions-persistence",
     description="An extension to add simple custom_id encoding to interactions.py.",
-    long_description=".",  # TODO
+    packages="interactions.ext.persistence"
 )
 
 def setup(bot):
